#include <gtk/gtk.h>
#include <stdio.h>
#include "main_screen.h"
#include "callback.h"
#include "call_dialog.h"
#include "misc.h"
#include "globals.h"
#include "menu.h"
#include <unistd.h>

extern "C"
{				// As we use g++
  GtkItemFactory *item_factory;
  static GtkItemFactoryEntry menu_items[] = {
    {"/_File", NULL, NULL, 0, "<Branch>"},
    {"/File/Send File", NULL, not_implemented, 0, NULL},
    {"/File/sep2", NULL, NULL, 0, "<Separator>"},
    {"/File/Log to File", NULL, not_implemented, 0, NULL},
    {"/File/Close Logfile", NULL, not_implemented, 0, NULL},
    {"/File/sep1", NULL, NULL, 0, "<Separator>"},
    {"/File/_Quit G-PSK31", "<ctl>Q", exit_dialog, 0, NULL},
    {"/_Settings", NULL, NULL, 0, "<Branch>"},
    {"/_Settings/Preferences", NULL, not_implemented, 0, NULL},
    {"/_Settings/sep1", NULL, NULL, 0, "<Separator>"},
    {"/_Settings/Fixtexts", NULL, NULL, 0, "<Branch>"},
    {"/_Settings/Fixtexts/Alt-Key-Fixtexts", NULL, not_implemented, 0, NULL},
    {"/_Settings/Fixtexts/Ctl-Key-Fixtexts", NULL, not_implemented, 0, NULL},
    {"/_Window", NULL, NULL, 0, "<Branch>"},
    {"/_Window/Contacts during this session", NULL, not_implemented, 0, "<CheckItem>"},
    {"/_Window/Previous Contacts", NULL, not_implemented, 0, "<CheckItem>"},
    {"/_Window/QSO Details", "<>F10", toggle_call_dialog, 0, "<CheckItem>"},
    {"/_Logbook", NULL, NULL, 0, "<Branch>"},
    {"/_Logbook/Search Data", NULL, not_implemented, 0, NULL},
    {"/_Help", NULL, NULL, 0, "<LastBranch>"},
    {"/_Help/_About G-PSK31", "<ctl>A", about_dialog, 0, NULL},
    {"/_Help/G-PSK31 Users Guide", NULL, not_implemented, 0, NULL}
  };
}


void
init_menu ()
{
  GtkAccelGroup *accel_group;
  gint nmenu_items = sizeof (menu_items) / sizeof (menu_items[0]);

  accel_group = gtk_accel_group_new ();


  item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>",
				       accel_group);

  gtk_item_factory_create_items (item_factory, nmenu_items, menu_items, NULL);

  gtk_accel_group_attach (accel_group, GTK_OBJECT (main_screen.window));

  main_screen.menu = gtk_item_factory_get_widget (item_factory, "<main>");
  
}

void about_dialog()
{
   static GtkWidget	*window;
   static GtkWidget	*label; 
   static GtkWidget	*ok_button;

   window = gtk_dialog_new();
   gtk_window_set_title (GTK_WINDOW (window),
                        "About G-PSK31");
   label = gtk_label_new ("\n"PACKAGE" - Linux GTK+ PSK31 Terminal\n" \
		          "Version "VERSION" - "DATE"\n\n" \
			  "DSP Routines by Hansi Reiser, DL9RDZ\n" \
			  " GTK+ GUI by Luc Langehegermann, LX2GT \n");
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_set_name (label, "about_label");  /* Name for rc lookup */
   ok_button = gtk_button_new_with_label ("OK");
   gtk_widget_set_usize (ok_button, 75, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area), ok_button, TRUE, FALSE, 0);
   gtk_window_set_policy (GTK_WINDOW (window), 0, 0, 0);
   gtk_widget_grab_focus (ok_button);

   gtk_signal_connect_object (GTK_OBJECT (ok_button), "clicked",
		       GTK_SIGNAL_FUNC (gtk_widget_hide), GTK_OBJECT (window));

   gtk_widget_show_all (window);
}

void exit_dialog()
{
   static GtkWidget    *window;
   static GtkWidget    *label;
   static GtkWidget    *yes_button;
   static GtkWidget    *no_button;

   window = gtk_dialog_new();
   gtk_window_set_title (GTK_WINDOW (window),
                        "Quit G-PSK31?");
   label = gtk_label_new ("\nDo you really want to quit?\n"); 
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_set_name (label, "about_label");  /* Name for rc lookup */
   yes_button = gtk_button_new_with_label ("Yes");
   gtk_widget_set_usize (yes_button, 75, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area), yes_button, TRUE, FALSE, 0);
   no_button = gtk_button_new_with_label ("No");
   gtk_widget_set_usize (no_button, 75, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area), no_button, TRUE, FALSE, 0);
   gtk_window_set_policy (GTK_WINDOW (window), 0, 0, 0);
   gtk_widget_grab_focus (no_button);
   gtk_widget_show_all (window);

   gtk_signal_connect_object (GTK_OBJECT (no_button), "clicked",
                       GTK_SIGNAL_FUNC (gtk_widget_destroy), GTK_OBJECT (window));

   gtk_signal_connect (GTK_OBJECT (yes_button), "clicked",
			GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
}

void not_implemented ()
{
   static GtkWidget     *window;
   static GtkWidget     *label;
   static GtkWidget     *ok_button;

   window = gtk_dialog_new();
   gtk_window_set_title (GTK_WINDOW (window),
                        "Information");
   label = gtk_label_new ("\nThis function is not yet available!\n");
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_set_name (label, "about_label");  /* Name for rc lookup */
   ok_button = gtk_button_new_with_label ("OK");
   gtk_widget_set_usize (ok_button, 75, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area), ok_button, TRUE, FALSE, 0);
   gtk_window_set_policy (GTK_WINDOW (window), 0, 0, 0);
   gtk_widget_grab_focus (ok_button);

   gtk_signal_connect_object (GTK_OBJECT (ok_button), "clicked",
                       GTK_SIGNAL_FUNC (gtk_widget_hide), GTK_OBJECT (window));

   gtk_widget_show_all (window);
}

void uncheck_qso_details_menu()				/* This unchecks the qso_details_menu */
{
    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (gtk_item_factory_get_item (item_factory,
                                                        "/Window/QSO Details")),
                                      FALSE);

}
